==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/search/variables_6c.js <==
var searchData=
[
  ['l',['l',['../structplplot_1_1__N10.html#afcbd008f747cde61aff7c5ed649367d7',1,'plplot::_N10::l()'],['../structPLControlPt.html#a26d940f8a935f7e39201e48e445fa17f',1,'PLControlPt::l()']]],
  ['label',['label',['../plplot__octave_8h.html#ae19a0553a7de117dfda2142edb0ee8ba',1,'plplot_octave.h']]],
  ['label_5fdata',['label_data',['../structPLStream.html#ac9452129be862814a5f6f8077e57b595',1,'PLStream']]],
  ['label_5ffunc',['label_func',['../structPLStream.html#af4b069a524cea0e41228216a8ed92333',1,'PLStream']]],
  ['label_5fobjs',['label_objs',['../tclAPI_8c.html#a65f251f166bca0f7552e3e7859945593',1,'tclAPI.c']]],
  ['label_5fopts',['label_opts',['../plplot__octave_8h.html#a9c8a65b0c7f26434e4988c4fbf2d56a7',1,'plplot_octave.h']]],
  ['labelclass',['labelClass',['../plplotjavacJAVA__wrap_8c.html#aeed8f4e8890c229ace508a90a2d3aafa',1,'plplotjavacJAVA_wrap.c']]],
  ['labelclassref',['labelClassRef',['../plplotjavacJAVA__wrap_8c.html#a5110e486a55c164c758481573735a45a',1,'plplotjavacJAVA_wrap.c']]],
  ['labtop',['labtop',['../structPLStrip.html#ac3f042bf3d947617ab9ac9da2757ac57',1,'PLStrip']]],
  ['labx',['labx',['../structPLStrip.html#a48334d81f31d05e9fc7aa548545982f6',1,'PLStrip']]],
  ['laby',['laby',['../structPLStrip.html#aedab1a3f86ef68aa7a64d7a273fd610b',1,'PLStrip']]],
  ['lasthandle',['lastHandle',['../ltdl__win32_8c.html#ac6e4bea73c8ef7abcf886676be760f91',1,'ltdl_win32.c']]],
  ['lastx',['lastx',['../plline_8c.html#a73547d0764c02f62b6d5d61825a9b1a9',1,'plline.c']]],
  ['lasty',['lasty',['../plline_8c.html#a225572be6d20e803b0f41070d2ee71bc',1,'plline.c']]],
  ['lcolor',['lcolor',['../structcdImageStruct.html#ad451df8654d31f9b0db8a1fb28fde573',1,'cdImageStruct']]],
  ['legline',['legline',['../structPLStrip.html#aa0b10d5bc8955aadb045b1c651fec3db',1,'PLStrip']]],
  ['len',['len',['../structtclMatrix.html#afdcff3698b42f36cd218fff46d8cd060',1,'tclMatrix']]],
  ['level',['level',['../structPLCairo.html#af57987cd3ce46b527343a0084f2b1345',1,'PLCairo::level()'],['../structcont__level.html#a1cb5b659388a526aec2152f5fd37d33a',1,'cont_level::level()'],['../structPLStream.html#acd3c7bd327b3301c1959ae2d6a16a5b3',1,'PLStream::level()']]],
  ['lib_5finitialized',['lib_initialized',['../plcore_8h.html#a55ce2b729b0a00653bd819cc02c67aa1',1,'plcore.h']]],
  ['libdir',['libdir',['../classplplot_1_1core_1_1config.html#a74f0aa66840fcddfe5382146b06d7526',1,'plplot::core::config']]],
  ['libname',['libname',['../classplplot_1_1core_1_1config.html#a34a8db24d643fe216e9ee409b4032018',1,'plplot::core::config']]],
  ['limexp',['limexp',['../plcont_8c.html#a8d119a389769dba9f8af39f10d825732',1,'plcont.c']]],
  ['line',['line',['../structcont__level.html#a819e8102f2953262b2b5986ad35716f1',1,'cont_level::line()'],['../plsdef_8c.html#acfd2f6c95701b9b51af015200017821a',1,'line():&#160;plsdef.c']]],
  ['line_5fstyle',['line_style',['../structPLStream.html#afea53ffa59a6a6e59edb4b79bf9f3189',1,'PLStream']]],
  ['linepos',['linepos',['../structPLStream.html#a91a227495bcc5009ee13647d77339dbc',1,'PLStream']]],
  ['linespacing',['lineSpacing',['../classwxPLDevBase.html#a5c8800de338216cc9aa1181a8f54b19a',1,'wxPLDevBase']]],
  ['linespec',['linespec',['../structcdImageStruct.html#a97e48cdd4944a26a3e868e95e3996147',1,'cdImageStruct']]],
  ['listlen',['listlen',['../structcdImageStruct.html#a919904acedb8fe1cd5d3bf982dd94cc8',1,'cdImageStruct']]],
  ['llx',['llx',['../structPSDev.html#a2292869483e90d8ba0cd6cda48a0d892',1,'PSDev']]],
  ['lly',['lly',['../structPSDev.html#a655dbb8d43059a8dac575dac6f8df2ef',1,'PSDev']]],
  ['lnan',['lNaN',['../csa_2nan_8h.html#a3c6818320c46b1d28eec452e2346ed3a',1,'lNaN():&#160;nan.h'],['../nn_2nan_8h.html#a3c6818320c46b1d28eec452e2346ed3a',1,'lNaN():&#160;nan.h']]],
  ['locate_5fmode',['locate_mode',['../classwxPLDevBase.html#a84b8e929feab8497335da57e118efcf9',1,'wxPLDevBase::locate_mode()'],['../structTkDev.html#acc3856b679b1088c1dc1d6d5e8859fb1',1,'TkDev::locate_mode()'],['../structTkwDev.html#a862e4df6954fdad6f1276e64f8cc6a22',1,'TkwDev::locate_mode()'],['../structXwDev.html#a6672c7cb85c3c10b8bb700a44a0f0dac',1,'XwDev::locate_mode()']]],
  ['locateeh',['LocateEH',['../structPLStream.html#a8646f5179b4c58935ab68589634b2a49',1,'PLStream']]],
  ['locateeh_5fdata',['LocateEH_data',['../structPLStream.html#a46802dd3b80c5fcd380bd6245427981a',1,'PLStream']]],
  ['lookup',['lookup',['../structPSDev.html#a5291c186d261373fe1d75478fa436f03',1,'PSDev']]],
  ['low_5fcap_5fcolor',['low_cap_color',['../plplot__octave_8h.html#a212e1687a384e97ea1cbe346036dfd31',1,'plplot_octave.h']]],
  ['ltype',['ltype',['../structcdImageStruct.html#abc7dab3130422f2d88410e08556ecf52',1,'cdImageStruct']]],
  ['lvalue',['lvalue',['../structswig__lua__const__info.html#a0f4d6393367808867778882594520a44',1,'swig_lua_const_info::lvalue()'],['../structswig__const__info.html#af142e4c21ad4fe61f6c2624bff034583',1,'swig_const_info::lvalue()']]],
  ['lwidth',['lwidth',['../structcdImageStruct.html#aa930e2446980608e181fa534484aeb02',1,'cdImageStruct']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/variables_6c.js <==
var searchData=
[
  ['l',['l',['../structplplot_1_1__N10.html#afcbd008f747cde61aff7c5ed649367d7',1,'plplot::_N10::l()'],['../structPLControlPt.html#a26d940f8a935f7e39201e48e445fa17f',1,'PLControlPt::l()']]],
  ['label_5fdata',['label_data',['../structPLStream.html#ac9452129be862814a5f6f8077e57b595',1,'PLStream']]],
  ['label_5ffunc',['label_func',['../structPLStream.html#af4b069a524cea0e41228216a8ed92333',1,'PLStream']]],
  ['label_5fobjs',['label_objs',['../tclAPI_8c.html#a65f251f166bca0f7552e3e7859945593',1,'tclAPI.c']]],
  ['labelclass',['labelClass',['../plplotjavacJAVA__wrap_8c.html#aeed8f4e8890c229ace508a90a2d3aafa',1,'plplotjavacJAVA_wrap.c']]],
  ['labelclassref',['labelClassRef',['../plplotjavacJAVA__wrap_8c.html#a5110e486a55c164c758481573735a45a',1,'plplotjavacJAVA_wrap.c']]],
  ['labtop',['labtop',['../structPLStrip.html#ac3f042bf3d947617ab9ac9da2757ac57',1,'PLStrip']]],
  ['labx',['labx',['../structPLStrip.html#a48334d81f31d05e9fc7aa548545982f6',1,'PLStrip']]],
  ['laby',['laby',['../structPLStrip.html#aedab1a3f86ef68aa7a64d7a273fd610b',1,'PLStrip']]],
  ['lasthandle',['lastHandle',['../ltdl__win32_8c.html#ac6e4bea73c8ef7abcf886676be760f91',1,'ltdl_win32.c']]],
  ['lastx',['lastx',['../plline_8c.html#a73547d0764c02f62b6d5d61825a9b1a9',1,'plline.c']]],
  ['lasty',['lasty',['../plline_8c.html#a225572be6d20e803b0f41070d2ee71bc',1,'plline.c']]],
  ['lcolor',['lcolor',['../structcdImageStruct.html#ad451df8654d31f9b0db8a1fb28fde573',1,'cdImageStruct']]],
  ['legline',['legline',['../structPLStrip.html#aa0b10d5bc8955aadb045b1c651fec3db',1,'PLStrip']]],
  ['len',['len',['../structtclMatrix.html#afdcff3698b42f36cd218fff46d8cd060',1,'tclMatrix']]],
  ['level',['level',['../structPLCairo.html#af57987cd3ce46b527343a0084f2b1345',1,'PLCairo::level()'],['../structcont__level.html#a1cb5b659388a526aec2152f5fd37d33a',1,'cont_level::level()'],['../structPLStream.html#acd3c7bd327b3301c1959ae2d6a16a5b3',1,'PLStream::level()']]],
  ['lib_5finitialized',['lib_initialized',['../plcore_8h.html#a55ce2b729b0a00653bd819cc02c67aa1',1,'plcore.h']]],
  ['libdir',['libdir',['../classplplot_1_1core_1_1config.html#a74f0aa66840fcddfe5382146b06d7526',1,'plplot::core::config']]],
  ['libname',['libname',['../classplplot_1_1core_1_1config.html#a34a8db24d643fe216e9ee409b4032018',1,'plplot::core::config']]],
  ['limexp',['limexp',['../plcont_8c.html#a8d119a389769dba9f8af39f10d825732',1,'plcont.c']]],
  ['line',['line',['../structcont__level.html#a819e8102f2953262b2b5986ad35716f1',1,'cont_level::line()'],['../plsdef_8c.html#acfd2f6c95701b9b51af015200017821a',1,'line():&#160;plsdef.c']]],
  ['line_5fstyle',['line_style',['../structPLStream.html#afea53ffa59a6a6e59edb4b79bf9f3189',1,'PLStream']]],
  ['linepos',['linepos',['../structPLStream.html#a91a227495bcc5009ee13647d77339dbc',1,'PLStream']]],
  ['linespec',['linespec',['../structcdImageStruct.html#a97e48cdd4944a26a3e868e95e3996147',1,'cdImageStruct']]],
  ['listlen',['listlen',['../structcdImageStruct.html#a919904acedb8fe1cd5d3bf982dd94cc8',1,'cdImageStruct']]],
  ['llx',['llx',['../structPSDev.html#a2292869483e90d8ba0cd6cda48a0d892',1,'PSDev']]],
  ['lly',['lly',['../structPSDev.html#a655dbb8d43059a8dac575dac6f8df2ef',1,'PSDev']]],
  ['lnan',['lNaN',['../csa_2nan_8h.html#a3c6818320c46b1d28eec452e2346ed3a',1,'lNaN():&#160;nan.h'],['../nn_2nan_8h.html#a3c6818320c46b1d28eec452e2346ed3a',1,'lNaN():&#160;nan.h']]],
  ['locate_5fmode',['locate_mode',['../structTkDev.html#acc3856b679b1088c1dc1d6d5e8859fb1',1,'TkDev::locate_mode()'],['../structTkwDev.html#a862e4df6954fdad6f1276e64f8cc6a22',1,'TkwDev::locate_mode()'],['../structXwDev.html#a6672c7cb85c3c10b8bb700a44a0f0dac',1,'XwDev::locate_mode()']]],
  ['locateeh',['LocateEH',['../structPLStream.html#a8646f5179b4c58935ab68589634b2a49',1,'PLStream']]],
  ['locateeh_5fdata',['LocateEH_data',['../structPLStream.html#a46802dd3b80c5fcd380bd6245427981a',1,'PLStream']]],
  ['locatemodeflag',['locateModeFlag',['../structMemoryMapHeader.html#acc8d6da9d5f88513902a693b87739982',1,'MemoryMapHeader']]],
  ['lookup',['lookup',['../structPSDev.html#a5291c186d261373fe1d75478fa436f03',1,'PSDev']]],
  ['lp_5foffset',['lp_offset',['../structPLmDev.html#a60695ba733373e9f52e931ab4ef77d26',1,'PLmDev']]],
  ['ltype',['ltype',['../structcdImageStruct.html#abc7dab3130422f2d88410e08556ecf52',1,'cdImageStruct']]],
  ['lvalue',['lvalue',['../structswig__lua__const__info.html#a0f4d6393367808867778882594520a44',1,'swig_lua_const_info::lvalue()'],['../structswig__const__info.html#af142e4c21ad4fe61f6c2624bff034583',1,'swig_const_info::lvalue()']]],
  ['lwidth',['lwidth',['../structcdImageStruct.html#aa930e2446980608e181fa534484aeb02',1,'cdImageStruct']]]
];
